<?php

/**
 * @file
 * This is a very quick prototype of a localized Drupal installer.
 */

/**
 * Implements hook_form_FORM_ID_alter().
 *
 * Allows the profile to alter the site configuration form.
 */
function yaml_l10n_install_form_install_configure_form_alter(&$form, $form_state) {
  // Pre-populate the site name with the server name.
  $form['site_information']['site_name']['#default_value'] = $_SERVER['SERVER_NAME'];
}

/**
 * Implement hook_install_tasks().
 */
function yaml_l10n_install_install_tasks($install_state) {
  return array(
    'yaml_l10n_install_configure_translations_form' => array(
      'display_name' => st('Additional languages'),
      'type' => 'form',
    ),
    'yaml_l10n_install_import_translation' => array(
      'display_name' => st('Import translations'),
      'type' => 'batch',
    ),
  );
}

/**
 * Implement hook_install_tasks_alter().
 *
 * Perform actions to set up the site for this profile.
 */
function yaml_l10n_install_install_tasks_alter(&$tasks, $install_state) {
  // Remove core steps for translation imports.
  unset($tasks['install_import_locales']);
  unset($tasks['install_import_locales_remaining']);
}


/**
 * Installation task callback: returns the form allowing the user to select
 * additional languages to install.
 */
function yaml_l10n_install_configure_translations_form() {
  // Provides predefined country list.
  include_once DRUPAL_ROOT . '/includes/iso.inc';
  $languages = _locale_prepare_predefined_list();

  $form['translations'] = array(
    '#type' => 'select',
    '#title' => st('Additional languages'),
    '#description' => st('Select additional languages to enable and download contributed interface translations.'),
    '#options' => $languages,
    '#multiple' => TRUE,
    '#size' => 10,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => st('Install selected languages'),
  );

  return $form;
}

/**
 * Submit callback: saves selected languages to be processed on the next step.
 */
function yaml_l10n_install_configure_translations_form_submit(&$form, &$form_state) {
  variable_set('yaml_l10n_install_selected_languages', $form_state['values']['translations']);
}

/**
 * Installation step callback.
 *
 * @param $install_state
 *   An array of information about the current installation state.
 */
function yaml_l10n_install_import_translation(&$install_state) {
  // Enable installation language as default site language.
  include_once DRUPAL_ROOT . '/includes/locale.inc';
  
  $default_language = $install_state['parameters']['locale'];
  $languages = variable_get('yaml_l10n_install_selected_languages', array());

  // Make sure the default language is added, too.
  $languages = array_merge(array($default_language => $default_language), $languages);
  
  if (!empty($languages)) {
    // No need to keep this variable.
    variable_del('yaml_l10n_install_selected_languages');

    // Add languages.
    foreach ($languages as $language) {
      $is_default_language = ($default_language == $language) ? TRUE : FALSE;
      locale_add_language($language, NULL, NULL, NULL, '', NULL, 1, $is_default_language);
    }

    // Fetch and batch the translations! https://www.drupal.org/node/2316291
    module_load_include('fetch.inc', 'l10n_update');
    $options = _l10n_update_default_update_options();
    $last_checked = variable_get('l10n_update_last_check');
    if ($last_checked < REQUEST_TIME - L10N_UPDATE_STATUS_TTL) {
      l10n_update_clear_status();
      $batch = l10n_update_batch_update_build(array(), $languages, $options);
    }
    else {
      $batch = l10n_update_batch_fetch_build(array(), $languages, $options);
    }
    return $batch;
  }
}
